use lazy_static::lazy_static;

lazy_static! {
    pub static ref CONFIG: Config = Config::read();
}

pub struct Config {
    pub gitlab_id: String,
    pub gitlab_secret: String,
    pub gitlab_url: String,
    pub gitlab_api_url: String,
    pub gitlab_redirect_url: String,
    pub smtp_server: String,
    pub smtp_port: u16,
    pub smtp_user: String,
    pub smtp_password: String
}

impl Config {
    fn read() -> Self {
        let config = std::fs::read_to_string("config.json").expect("Failed to read config.json");
        let config = json::parse(config.as_str()).expect("Failed to parse config.json");
        Self {
            gitlab_id: config["gitlab_id"].as_str().expect("Config is missing 'gitlab_id'").to_string(),
            gitlab_secret: config["gitlab_secret"].as_str().expect("Config is missing 'gitlab_secret'").to_string(),
            gitlab_url: config["gitlab_url"].as_str().expect("Config is missing 'gitlab_url'").to_string(),
            gitlab_api_url: config["gitlab_api_url"].as_str().expect("Config is missing 'gitlab_api_url'").to_string(),
            gitlab_redirect_url: config["gitlab_redirect_url"].as_str().expect("Config is missing 'gitlab_redirect_url'").to_string(),
            smtp_server: config["smtp_server"].as_str().expect("Config is missing 'smtp_server'").to_string(),
            smtp_port: config["smtp_port"].as_u16().expect("Config is missing 'smtp_port'"),
            smtp_user: config["smtp_user"].as_str().expect("Config is missing 'smtp_user'").to_string(),
            smtp_password: config["smtp_password"].as_str().expect("Config is missing 'smtp_password'").to_string()
        }
    }
}