use warp::{Filter, Reply};
use crate::db::{DBConnection, DBPool, with_db};
use crate::dto;
use crate::routes::get_reply;
use crate::routes::filters::{authenticated, UserInfo};

pub fn build_routes(db: DBPool) -> impl Filter<Extract = impl Reply, Error = warp::Rejection> + Clone {
    let info = warp::path!("user" / "info")
        .and(warp::get())
        .and(authenticated(db.clone()))
        .and_then(info);
    let delete_user = warp::path!("user" / "delete")
        .and(warp::post())
        .and(authenticated(db.clone()))
        .and(with_db(db))
        .and_then(delete_user);

    info.or(delete_user)
}

async fn info(info: UserInfo) -> Result<impl Reply, warp::Rejection> {
    get_reply(&dto::responses::UserInfo {
        statusCode: info.0.id,
        name: info.0.name,
        gitlab: info.0.gitlab,
        tfaEnabled: info.0.tfa_type != crate::db::TfaTypes::None
    })
}

async fn delete_user(info: UserInfo, mut db: DBConnection) -> Result<impl Reply, warp::Rejection> {
    db.delete_all_tokens(info.0.id);

    let root_node = super::fs::get_node_and_validate(&info.0, info.0.root_id, &mut db).expect("Failed to get root node for deleting");

    super::fs::delete_node_root(&root_node, &mut db);

    db.delete_user(&info.0);

    get_reply(&dto::responses::Success {
        statusCode: 200
    })
}